@@ -158,16 +158,13 @@ sub EditFieldRender {
             $DataValues = { $Value => $Value };
         }
     }
-    elsif ( !IsHashRefWithData($DataValues) ) {
-        $DataValues = { ' ' => ' ' };
-    }
 
     my $HTMLString = $Param{LayoutObject}->BuildSelection(
         Data         => $DataValues || {},
         Name         => $FieldName,
         SelectedID   => $SelectedValuesArrayRef,
         Translation  => $FieldConfig->{TranslatableValues} || 0,
-        PossibleNone => 0,
+        PossibleNone => 1,
         TreeView     => $FieldConfig->{TreeView} || 0,
         Class        => $FieldClass,
         HTMLQuote    => 1,
@@ -558,7 +555,7 @@ sub SearchFieldRender {
         Name         => $FieldName,
         SelectedID   => $Value,
         Translation  => $FieldConfig->{TranslatableValues} || 0,
-        PossibleNone => 0,
+        PossibleNone => 1,
         TreeView     => $FieldConfig->{TreeView} || 0,
         Class        => $FieldClass,
         Multiple     => 1,
@@ -620,18 +617,12 @@ sub _AutocompleteSearchFieldRender {
         );
     }
 
-    if ( !IsHashRefWithData($SelectionData) ) {
-        $SelectionData = {
-            ' ' => ' ',
-        };
-    }
-
     my $HTMLString = $Param{LayoutObject}->BuildSelection(
         Data         => $SelectionData,
         Name         => $FieldName,
         SelectedID   => $FieldValues,
         Translation  => $FieldConfig->{TranslatableValues} || 0,
-        PossibleNone => 0,
+        PossibleNone => 1,
         TreeView     => 0,
         Class        => $FieldClass,
         Multiple     => 1,
@@ -877,16 +868,11 @@ sub PossibleValuesGet {
     my $DynamicFieldWebserviceObject = $Kernel::OM->Get('Kernel::System::DynamicField::Webservice');
     my $LayoutObject                 = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
 
-    # to store the possible values
     my %PossibleValues;
 
-    # set PossibleNone attribute
-    my $FieldPossibleNone = 1;
-
-    # set none value if defined on field config
-    if ( $FieldPossibleNone || !$Param{Value} ) {
-        %PossibleValues = ( ' ' => '-' );
-    }
+    # Provide empty value so the field will not be displayed as disabled if there are no selectable
+    # values yet.
+    $PossibleValues{' '} = '';
 
     if ( $Param{DynamicFieldConfig}->{Config}->{InitialSearchTerm} ) {
         my $InitialSearchTerm = $LayoutObject->Ascii2Html(
